@@ -3,16 +3,18 @@
 #' It converts a SCOPUS, Clarivate Analytics WoS, Dimensions, Lens.org, PubMed and COCHRANE Database export files or pubmedR and dimensionsR JSON/XML 
 #' objects into a data frame, with cases corresponding to articles and variables to Field Tags as used in WoS.
 #'
-#' @param file a character array containing a sequence of object names coming from: 
+#' @param file a character array containing a sequence of filenames coming from WoS, Scopus, Dimensions, Lens.org, and Pubmed. Alternatively, \code{file} can be 
+#' an object resulting from an API query fetched from Dimensions, PubMed or OpenAlex databases: 
 #' \tabular{lll}{
-#' a)\tab \tab Clarivate Analytics WoS (in plaintext '.txt', Endnote Desktop '.ciw', or bibtex formats '.bib');\cr
-#' b)\tab \tab SCOPUS (exclusively in bibtex format '.bib');\cr
-#' c)\tab \tab Digital Science Dimensions (in csv '.csv' or excel '.xlsx' formats);\cr
-#' d)\tab \tab Lens.org (in csv '.csv');\cr
-#' e)\tab \tab an object of the class \code{pubmedR (package pubmedR)} containing a collection obtained from a query performed with pubmedR package;\cr
-#' f)\tab \tab an object of the class \code{dimensionsR (package dimensionsR)} containing a collection obtained from a query performed with dimensionsR package.}
-#' @param dbsource is a character indicating the bibliographic database. \code{dbsource} can be \code{"isi"}, \code{"wos"}, \code{"scopus"}, \code{"dimensions"} or \code{"pubmed"}. Default is \code{dbsource = "isi"}.
-#' @param format is a character indicating the format of the SCOPUS and Clarivate Analytics WoS export file. \code{format} can be \code{"api"}, \code{"bibtex"}, \code{"plaintext"}, \code{"endnote"}, \code{"csv"} or \code{"excel"}. Default is \code{format = "plaintext"}.
+#' a)\tab 'wos' \tab Clarivate Analytics WoS (in plaintext '.txt', Endnote Desktop '.ciw', or bibtex formats '.bib');\cr
+#' b)\tab 'scopus' \tab SCOPUS (exclusively in bibtex format '.bib');\cr
+#' c)\tab 'dimensions' \tab Digital Science Dimensions (in csv '.csv' or excel '.xlsx' formats);\cr
+#' d)\tab 'lens' \tab Lens.org (in csv '.csv');\cr
+#' e)\tab 'pubmed' \tab an object of the class \code{pubmedR (package pubmedR)} containing a collection obtained from a query performed with pubmedR package;\cr
+#' f)\tab 'dimensions' \tab an object of the class \code{dimensionsR (package dimensionsR)} containing a collection obtained from a query performed with dimensionsR package;\cr
+#' g)\tab 'openalex' \tab a data frame object returned by openalexR package, containing a collection of works resulting from a query fetched from OpenAlex database.}
+#' @param dbsource is a character indicating the bibliographic database. \code{dbsource} can be \code{dbsource = c('cochrane','dimensions','generic','isi','openalex', 'pubmed','scopus','wos', 'lens')} . Default is \code{dbsource = "isi"}.
+#' @param format is a character indicating the format of the SCOPUS and Clarivate Analytics WoS export file. \code{format} can be \code{c('api', 'bibtex', 'csv', 'endnote','excel','plaintext', 'pubmed')}. Default is \code{format = "plaintext"}.
 #' @return a data frame with cases corresponding to articles and variables to Field Tags in the original export file.
 #' 
 #' I.e We have three files downlaod from Web of Science in plaintext format, file will be:
@@ -58,7 +60,7 @@
 convert2df<-function(file,dbsource="wos",format="plaintext"){
 
   allowed_formats <- c('api', 'bibtex', 'csv', 'endnote','excel','plaintext', 'pubmed') 
-  allowed_db <- c('cochrane','dimensions','generic','isi','pubmed','scopus','wos', 'lens')
+  allowed_db <- c('cochrane','dimensions','generic','isi','openalex', 'pubmed','scopus','wos', 'lens')
   
   cat("\nConverting your",dbsource,"collection into a bibliographic dataframe\n\n")
   if (length(setdiff(dbsource,allowed_db))>0){
@@ -70,10 +72,11 @@ convert2df<-function(file,dbsource="wos",format="plaintext"){
     cat("\n 'format' argument has to be a character string matching one among:",allowed_formats,"\n")
   }
   
-  ### da controllare
-  if (length(setdiff(format,c("api","plaintext","bibtex","csv","excel", "endnote")))>0){
-    D <- importFiles(file)
-    D <- iconv(D, "latin1", "ASCII", sub="")}
+  # ### da controllare
+  # if (length(setdiff(format,c("api","plaintext","bibtex","csv","excel", "endnote")))>0){
+  #   D <- importFiles(file)
+  #   D <- iconv(D, "latin1", "ASCII", sub="")}
+  # ####
   
   if (dbsource=="wos") dbsource <- "isi"
   if (format=="endnote") format <- "plaintext"
@@ -143,6 +146,13 @@ convert2df<-function(file,dbsource="wos",format="plaintext"){
                M$DB <- "DIMENSIONS"
              })
       
+    },
+    openalex = {
+      if (!"bibliometrixDB" %in% class(file)){
+        M <- openalexR::oa2bibliometrix(file)
+      } else {
+        M <- file
+      }
     }
   )
   if ("PY" %in% names(M)){M$PY=as.numeric(M$PY)} else {M$PY <- NA}
@@ -162,7 +172,7 @@ convert2df<-function(file,dbsource="wos",format="plaintext"){
   
   cat("Done!\n\n")
   
-  if (!(dbsource %in% c("pubmed", "lens"))) {
+  if (!(dbsource %in% c("pubmed", "lens", "openalex"))) {
     ## AU_UN field creation
     if ("C1" %in% names(M)) {
       cat("\nGenerating affiliation field tag AU_UN from C1:  ")
@@ -184,7 +194,7 @@ convert2df<-function(file,dbsource="wos",format="plaintext"){
   if ((dbsource == "pubmed") & (format == "pubmed")) {
     if ("C1" %in% names(M)) {
       cat("\nGenerating affiliation field tag AU_UN from C1:  ")
-      
+
       M <- metaTagExtraction(M, Field = "AU_UN")
       cat("Done!\n\n")
     } else{
